"use strict";
// Copyright (c) Frédéric Maquin <fred@ephread.com>
// Licensed under the MIT License.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
const Fs = require("fs-extra");
const Path = require("path");
const vscode_languageserver_1 = require("vscode-languageserver");
const types_1 = require("./types");
/**
 * Returns `true` if `filePath` point to a file that is a child of
 * the directory `dirPath` points to.
 *
 * @param filePath path to he file.
 * @param dirPath path to the directory.
 */
function isFilePathChildOfDirPath(filePath, dirPath) {
    const relative = Path.relative(dirPath, filePath);
    return !!relative && !relative.startsWith("..") && !Path.isAbsolute(relative);
}
exports.isFilePathChildOfDirPath = isFilePathChildOfDirPath;
/**
 * Transform an InkErrorType into its equivalent DiagnosticSeverity.
 * @param type the InkErrorType to transform.
 */
function getDiagnosticSeverityFromInkErrorType(type) {
    switch (type) {
        case types_1.InkErrorType.RuntimeError:
        case types_1.InkErrorType.Error:
            return vscode_languageserver_1.DiagnosticSeverity.Error;
        case types_1.InkErrorType.RuntimeWarning:
        case types_1.InkErrorType.Warning:
            return vscode_languageserver_1.DiagnosticSeverity.Warning;
        case types_1.InkErrorType.Todo:
            return vscode_languageserver_1.DiagnosticSeverity.Information;
    }
}
exports.getDiagnosticSeverityFromInkErrorType = getDiagnosticSeverityFromInkErrorType;
function determinePlatform() {
    if (process.platform === "win32") {
        return types_1.Platform.Windows;
    }
    else if (process.platform === "darwin") {
        return types_1.Platform.MacOs;
    }
    return types_1.Platform.Other;
}
exports.determinePlatform = determinePlatform;
/**
 * Returns true if the current setup requires Inklecate to be run through mono.
 */
function isRunThroughMono() {
    const platform = determinePlatform();
    const isMacInklecateValid = (platform === types_1.Platform.MacOs && isDefaultMacOsInklecateInstalled());
    return !isMacInklecateValid && platform !== types_1.Platform.Windows;
}
exports.isRunThroughMono = isRunThroughMono;
/**
 * Returns the default path to inklecate depending on the given Platform.
 *
 * @param platform the Platform for which return the default inklecate path.
 */
function defaultInklecatePath(platform) {
    if (platform === types_1.Platform.MacOs && isDefaultMacOsInklecateInstalled()) {
        return defaultMacInklecatePath();
    }
    else {
        return Path.join(__dirname, "..", "vendor/inklecate.exe");
    }
}
exports.defaultInklecatePath = defaultInklecatePath;
/**
 * Merge the given settings with the default one,
 * replacing any empty or undefined values.
 *
 * @param settings the provided configuration settings.
 * @param defaultSettings the default settings to use if values are empty or undefined.
 */
function mergeSettings(settings, defaultSettings) {
    let inklecatePath = settings.inklecateExecutablePath;
    let mainStoryPath = settings.mainStoryPath;
    let runThroughMono = settings.runThroughMono;
    if (typeof inklecatePath === "undefined" || !inklecatePath || inklecatePath.length === 0) {
        inklecatePath = defaultSettings.inklecateExecutablePath;
    }
    if (typeof mainStoryPath === "undefined" || !mainStoryPath || mainStoryPath.length === 0) {
        mainStoryPath = defaultSettings.mainStoryPath;
    }
    if (typeof runThroughMono === "undefined") {
        runThroughMono = defaultSettings.runThroughMono;
    }
    return {
        inklecateExecutablePath: inklecatePath,
        mainStoryPath,
        runThroughMono
    };
}
exports.mergeSettings = mergeSettings;
/**
 * Returns given string with escaped characters, for use as a regular expression pattern.
 *
 * @param source the string to escape
 */
function escapeForRegExp(source) {
    return source.replace(/[\\^$*+?.()|[\]{}]/g, '\\$&');
}
exports.escapeForRegExp = escapeForRegExp;
/**
 * Returns the default path to inklecate, when running the server on macOS.
 */
function defaultMacInklecatePath() {
    return Path.join(__dirname, "..", "vendor/inklecate");
}
/**
 * Return true if the default macos prebuilt binary was
 * successfully downloaded un unpacked.
 */
function isDefaultMacOsInklecateInstalled() {
    try {
        const stat = Fs.statSync(defaultMacInklecatePath());
        return true;
    }
    catch (error) {
        return false;
    }
}
//# sourceMappingURL=utils.js.map